@@ -9,9 +9,6 @@
 #define _LIBVKONTAKTE_INTERFACE_H_
 
 #include <glib.h>
-//#include <sharing-account.h>
-//#include <sharing-transfer.h>
-//#include <sharing-entry.h>
 #include <sharing-plugin-interface.h>
 #include <sharing-service-option.h>
 #include <dlfcn.h>
@@ -24,7 +21,6 @@
 #include <stdio.h>
 #include <mysocials_driver.h>
 #include <osso-log.h>
-//#include <sharing-http.h>
 
 #define MODULE_INIT "msa_module_init"
 #define XPATH_GET_ALBUM "//TransitData/Content/Response/Params/array[@name='albumList']"
@@ -38,17 +34,19 @@
 #define DRIVER_ID "vkontakte"
 #define NODE_SETTINGS "settings"
 
-#ifndef DEBUG
+#ifdef DEBUG
 #define msa_print(...) g_print(__VA_ARGS__)
+#define msa_debug(...) g_print(__VA_ARGS__)
 #else
 #define msa_print(...)
+#define msa_debug(...)
 #endif
 
 void* handle;
 struct msa_module* driver_module;
 gint (* driver_init)(struct msa_module*);
 
-gboolean libvk_init(gchar* proxy_host, gint proxy_port, gchar* account_name);
+gboolean libvk_init(ConIcConnection *conn, gchar* account_name);
 
 void libvk_uninit();
 
@@ -62,9 +60,9 @@ SharingPluginInterfaceSendResult libvk_getAlbums(GSList** list_album);
 
 gboolean libvk_uploadPhoto(gchar *aid, gchar *file, gchar *file_name);
 
-static xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc);
+xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc);
 
-static xmlXPathObject* xpath(gchar* req, xmlDocPtr doc);
+xmlXPathObject* xpath(gchar* req, xmlDocPtr doc);
 
 gboolean libvk_testConnection();
 
